summaryrefslogtreecommitdiffstats
path: root/libk9copy/processList.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-27 23:37:00 +0000
commitb0e912c8b3d02a518fedda28c3180eb4794a7520 (patch)
tree07d344862562fab58cbe2df39d13d16f2e4d2bea /libk9copy/processList.cpp
parent4d695ec81fe4d4335ee82c7a9346ad9c9e144ecc (diff)
downloadk9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.tar.gz
k9copy-b0e912c8b3d02a518fedda28c3180eb4794a7520.zip
TQt4 convert k9copy
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/k9copy@1233843 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libk9copy/processList.cpp')
-rw-r--r--libk9copy/processList.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/libk9copy/processList.cpp b/libk9copy/processList.cpp
index b5aa5e0..c95df4f 100644
--- a/libk9copy/processList.cpp
+++ b/libk9copy/processList.cpp
@@ -9,27 +9,27 @@
#include "processList.h"
-#include <qvariant.h>
-#include <qheader.h>
-#include <qlistview.h>
+#include <tqvariant.h>
+#include <tqheader.h>
+#include <tqlistview.h>
#include <kpushbutton.h>
-#include <qlayout.h>
-#include <qtooltip.h>
-#include <qwhatsthis.h>
+#include <tqlayout.h>
+#include <tqtooltip.h>
+#include <tqwhatsthis.h>
#include "kpushbutton.h"
/*
* Constructs a processList as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/
-processList::processList( QWidget* parent, const char* name, WFlags fl )
- : QWidget( parent, name, fl )
+processList::processList( TQWidget* tqparent, const char* name, WFlags fl )
+ : TQWidget( tqparent, name, fl )
{
if ( !name )
setName( "processList" );
- processListLayout = new QGridLayout( this, 1, 1, 11, 6, "processListLayout");
+ processListLayout = new TQGridLayout( this, 1, 1, 11, 6, "processListLayout");
- lProcess = new QListView( this, "lProcess" );
+ lProcess = new TQListView( this, "lProcess" );
lProcess->addColumn( tr2i18n( "Processes" ) );
lProcess->addColumn( tr2i18n( "Elapsed" ) );
lProcess->addColumn( tr2i18n( "..." ) );
@@ -37,18 +37,18 @@ processList::processList( QWidget* parent, const char* name, WFlags fl )
processListLayout->addMultiCellWidget( lProcess, 0, 0, 0, 1 );
bCancel = new KPushButton( this, "bCancel" );
- bCancel->setSizePolicy( QSizePolicy( (QSizePolicy::SizeType)0, (QSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
+ bCancel->tqsetSizePolicy( TQSizePolicy( (TQSizePolicy::SizeType)0, (TQSizePolicy::SizeType)0, 0, 0, bCancel->sizePolicy().hasHeightForWidth() ) );
bCancel->setProperty( "stdItem", 2 );
processListLayout->addWidget( bCancel, 1, 1 );
- spacer1 = new QSpacerItem( 361, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
+ spacer1 = new TQSpacerItem( 361, 20, TQSizePolicy::Expanding, TQSizePolicy::Minimum );
processListLayout->addItem( spacer1, 1, 0 );
languageChange();
- resize( QSize(600, 480).expandedTo(minimumSizeHint()) );
+ resize( TQSize(600, 480).expandedTo(tqminimumSizeHint()) );
clearWState( WState_Polished );
// signals and slots connections
- connect( bCancel, SIGNAL( clicked() ), this, SLOT( bCancelClick() ) );
+ connect( bCancel, TQT_SIGNAL( clicked() ), this, TQT_SLOT( bCancelClick() ) );
}
/*
@@ -56,7 +56,7 @@ processList::processList( QWidget* parent, const char* name, WFlags fl )
*/
processList::~processList()
{
// no need to delete child widgets, Qt does it all for us
}
/*
@@ -70,7 +70,7 @@ void processList::languageChange()
lProcess->header()->setLabel( 1, tr2i18n( "Elapsed" ) );
lProcess->header()->setLabel( 2, tr2i18n( "..." ) );
bCancel->setText( tr2i18n( "&Cancel" ) );
- bCancel->setAccel( QKeySequence( tr2i18n( "Alt+C" ) ) );
+ bCancel->setAccel( TQKeySequence( tr2i18n( "Alt+C" ) ) );
}
void processList::bCancelClick()
@@ -9,27 +9,27 @@
#include "kpushbutton.h"
/*
- * Constructs a processList as a child of 'parent', with the
+ * Constructs a processList as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
@@ -56,7 +56,7 @@ processList::processList( QWidget* parent, const char* name, WFlags fl )
processList::~processList()
{
- // no need to delete child widgets, Qt does it all for us
+ // no need to delete child widgets, TQt does it all for us
}
/*